@@ -1,18 +1,23 @@
 from datetime import datetime
+from types import TracebackType
+from typing import Optional
 
 from spark_pipeline_framework.progress_logger.progress_logger import ProgressLogger
 
 
 class ProgressLogMetric:
-    def __init__(self, name: str, progress_logger: ProgressLogger):
-        self.progress_logger: ProgressLogger = progress_logger
+    def __init__(self, name: str, progress_logger: Optional[ProgressLogger]):
+        self.progress_logger: Optional[ProgressLogger] = progress_logger
         self.name: str = name
         self.start_time: datetime = datetime.now()
 
-    def __enter__(self):
+    def __enter__(self) -> 'ProgressLogMetric':
         return self.start()
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def __exit__(
+        self, exc_type: Optional[BaseException],
+        exc_value: Optional[BaseException], traceback: Optional[TracebackType]
+    ) -> None:
         self.stop()
 
     def start(self) -> 'ProgressLogMetric':
@@ -31,4 +36,7 @@ class ProgressLogMetric:
             end_time: datetime = datetime.now()
             time_diff_in_minutes: float = (end_time - self.start_time
                                            ).total_seconds() // 60
-            self.progress_logger.log_metric(self.name, time_diff_in_minutes)
+            if self.progress_logger:
+                self.progress_logger.log_metric(
+                    self.name, time_diff_in_minutes
+                )
