@@ -58,9 +58,21 @@ class ProxyGenerator:
 
         if path_contains_transformer:
             for file in files:
-                if file.endswith(transformer_file_indicators):
+                translator_search_result: Optional[
+                    Match[str]] = search(r'/library/translators/', folder)
+                if translator_search_result:
                     search_result: Optional[Match[str]
                                             ] = search(r'/library/', folder)
+                    if search_result:
+                        transformer_reader_file_name = folder[
+                            search_result.end():].replace('/', '_')
+                        ProxyGenerator.write_translator(
+                            file_name=transformer_reader_file_name,
+                            folder=folder,
+                            csv_file=path.basename(file)
+                        )
+                elif file.endswith(transformer_file_indicators):
+                    search_result = search(r'/library/', folder)
                     if search_result:
                         transformer_reader_file_name = folder[
                             search_result.end():].replace('/', '_')
@@ -106,3 +118,28 @@ class {transformer_reader_class_name}(ProxyBase):
             with open(transformer_proxy_file_name, 'w+') as file:
                 print(f"Creating {transformer_proxy_file_name}")
                 file.write(transformer_reader_string)
+
+    @staticmethod
+    def write_translator(file_name: str, folder: str, csv_file: str) -> None:
+        translator_reader_class_name = ''.join(
+            [s.title() for s in file_name.split('_')]
+        )
+        transformer_reader_string = f"""from spark_pipeline_framework.proxy_generator.translator_proxy_base import TranslatorProxyBase
+from os import path
+
+
+# This file was auto-generated by generate_proxies(). It enables auto-complete in PyCharm. Do not edit manually!
+class {translator_reader_class_name}(TranslatorProxyBase):
+    def __init__(self
+                 ) -> None:
+        location: str = path.dirname(path.abspath(__file__))
+        super().__init__(
+            location=location,
+            csv_file="{csv_file}"
+        )
+"""
+        translator_proxy_file_name: str = path.join(folder, file_name + '.py')
+        if not path.exists(translator_proxy_file_name):
+            with open(translator_proxy_file_name, 'w+') as file:
+                print(f"Creating translator {translator_proxy_file_name}")
+                file.write(transformer_reader_string)
